"Regression.Integrator.PenReg.SelMin.FitObj"Class containing the output of fitting a PenReg-based integrator with CV-error minimization method for selecting the optimal shrinkage parameter.
Objects can be created by calls of the form new("Regression.Integrator.PenReg.SelMin.FitObj", ...).
config:Object of class "Regression.Integrator.Config", containing the error function and the partition to use for training the PenReg integrator.
est:Object of class "ANY", estimation object that is used for prediction.
pred:Object of class "numeric", prediction for training set.
Class "Regression.Integrator.FitObj-class", directly.
No methods defined with class "Regression.Integrator.PenReg.SelMin.FitObj" in the signature.
Mansour T.A. Sharabiani, Alireza S. Mahani
"Regression.Integrator.FitObj-class"